require 'test_helper'

class OrderTest < Minitest::Test
  def setup
    @order = Honey::Order.new
  end

  def teardown
    @order = nil
  end

  def test_update
    @order.update(last: "Shreve", items: [:item, :item])
    assert_equal "Shreve", @order.last
    assert_equal [:item, :item], @order.items
  end

  def test_validity
    assert @order.invalid?
    @order.required_attributes.each do |attr|
      @order.send("#{attr}=".to_sym, "hello")
    end
    assert @order.valid?
  end

  def test_present_attributes
    @order.update(last: "Shreve", first: "Jacob")
    assert_equal @order.present_attributes, [:last, :first]
  end

  def test_shipping_options_as_hash
    @order.shipping = { carrier: :USPS, service: "first class" }
    assert_equal "P003", @order.shipping
  end

  def test_shipping_option_from_api_code
    shipping_option = Honey::Order.shipping_option_from_api_code("P003")
    assert_equal "usps", shipping_option[:carrier]
    assert_equal "first class", shipping_option[:service]
  end
end
